@@ -121,26 +121,27 @@ class NeptuneExperimentTracker(ExperimentTracker):
         for (key, value) in valueMap.items():
             if isinstance(value, Figure):
                 fileHandle = BytesIO()
-                value.savefig(fileHandle, format="svg")
+                value.savefig(fileHandle, format="svg", bbox_inches="tight")
                 loggable[f"{path}/{key}"].upload(
                     File.from_stream(fileHandle, extension="svg")
                 )
-                loggable[f"{path}/{key} preview"].upload(File.as_image(value))
+                loggable[f"{path}/{key} preview"].upload(
+                    File.as_image(
+                        value.savefig(fileHandle, format="png", bbox_inches="tight")
+                    )
+                )
             elif isinstance(value, DataFrame):
                 tableStream = BytesIO()
                 value.to_csv(tableStream, header=True, index=True)
                 loggable[f"{path}/{key}"].upload(
                     File.from_stream(tableStream, extension="csv")
-                    # tempFileName
                 )
             elif key == "model":
                 loggable[f"{path}/{key}"].upload(
                     File.from_stream(BytesIO(value), extension="pkl")
                 )
-            elif isinstance(value, bytes):
-                loggable[f"{path}/{key}"].upload(
-                    File.from_stream(BytesIO(value), extension="bin")
-                )
+            elif isinstance(value, BytesIO) or isinstance(value, StringIO):
+                loggable[f"{path}/{key}"].upload(File.from_stream(value))
             else:
                 loggable[f"{path}/{key}"] = value
 
